searchData={"items":[{"type":"module","title":"Assent","doc":"Multi-provider authentication framework.","ref":"Assent.html"},{"type":"module","title":"Features - Assent","doc":"* Includes the following base strategies:\n  * OAuth 1.0 - `Assent.Strategy.OAuth`\n  * OAuth 2.0 - `Assent.Strategy.OAuth2`\n  * OpenID Connect - `Assent.Strategy.OIDC`\n* Includes the following provider strategies:\n  * Apple Sign In - `Assent.Strategy.Apple`\n  * Auth0 - `Assent.Strategy.Auth0`\n  * Azure AD - `Assent.Strategy.AzureAD`\n  * Basecamp - `Assent.Strategy.Basecamp`\n  * Bitbucket - `Assent.Strategy.Bitbucket`\n  * DigitalOcean - `Assent.Strategy.DigitalOcean`\n  * Discord - `Assent.Strategy.Discord`\n  * Facebook - `Assent.Strategy.Facebook`\n  * Github - `Assent.Strategy.Github`\n  * Gitlab - `Assent.Strategy.Gitlab`\n  * Google - `Assent.Strategy.Google`\n  * Instagram - `Assent.Strategy.Instagram`\n  * LINE Login - `Assent.Strategy.LINE`\n  * Linkedin - `Assent.Strategy.Linkedin`\n  * Spotify - `Assent.Strategy.Spotify`\n  * Strava - `Assent.Strategy.Strava`\n  * Slack - `Assent.Strategy.Slack`\n  * Stripe Connect - `Assent.Strategy.Stripe`\n  * Telegram - `Assent.Strategy.Telegram`\n  * Twitch - `Assent.Strategy.Twitch`\n  * Twitter - `Assent.Strategy.Twitter`\n  * VK - `Assent.Strategy.VK`\n  * Zitadel - `Assent.Strategy.Zitadel`","ref":"Assent.html#module-features"},{"type":"module","title":"Usage - Assent","doc":"A strategy consists of two phases; request and callback. In the request phase, the user will be redirected to the auth provider for authentication and then returned to initiate the callback phase.","ref":"Assent.html#module-usage"},{"type":"module","title":"Single provider - Assent","doc":"This is an example using the `Assent.Strategy.Github` strategy with `Plug`:\n\n```elixir\ndefmodule GithubAuth do\n  import Plug.Conn\n\n  alias Assent.Strategy.Github\n\n  defp config do\n    [\n      client_id: Application.fetch_env!(:my_app, :github, :client_id),\n      client_secret: Application.fetch_env!(:my_app, :github, :client_secret),\n      redirect_uri: \"http://localhost:4000/auth/github/callback\"\n    ]\n  end\n\n  # http://localhost:4000/auth/github\n  def request(conn) do\n    config()\n    |> Github.authorize_url()\n    |> case do\n      {:ok, %{url: url, session_params: session_params}} ->\n        # Session params (used for OAuth 2.0 and OIDC strategies) will be\n        # retrieved when user returns for the callback phase\n        conn = put_session(conn, :session_params, session_params)\n\n        # Redirect end-user to Github to authorize access to their account\n        conn\n        |> put_resp_header(\"location\", url)\n        |> send_resp(302, \"\")\n\n      {:error, _error} ->\n        # Something went wrong generating the request authorization url\n        send_resp(conn, 500, \"Failed authorization\")\n    end\n  end\n\n  # http://localhost:4000/auth/github/callback\n  def callback(conn) do\n    # End-user will return to the callback URL with params attached to the\n    # request. These must be passed on to the strategy. In this example we only\n    # expect GET query params, but the provider could also return the user with\n    # a POST request where the params is in the POST body.\n    %{params: params} = fetch_query_params(conn)\n\n    # The session params (used for OAuth 2.0 and OIDC strategies) stored in the\n    # request phase will be used in the callback phase\n    session_params = get_session(conn, :session_params)\n\n    conn = delete_session(conn, :session_params)\n\n    config()\n    # Session params should be added to the config so the strategy can use them\n    |> Keyword.put(:session_params, session_params)\n    |> Github.callback(params)\n    |> case do\n      {:ok, %{user: user, token: token}} ->\n        # Authorization succesful\n        conn\n        |> put_session(:user, user)\n        |> put_session(:token, token)\n        |> put_resp_header(\"location\", \"/\")\n        |> send_resp(302, \"\")\n\n      {:error, _error} ->\n        # Authorizaiton failed\n        send_resp(conn, 500, \"Failed authorization\")\n    end\n  end\nend\n```","ref":"Assent.html#module-single-provider"},{"type":"module","title":"Multi-provider - Assent","doc":"All assent strategies work the same way, so if you have more than one strategy you may want to set up a single module to handle any of the auth strategies. This example is a generalized flow that's similar to what's used in `PowAssent`.\n\n```elixir\nconfig :my_app, :strategies,\n  github: [\n    client_id: \"REPLACE_WITH_CLIENT_ID\",\n    client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n    strategy: Assent.Strategy.Github\n  ],\n  # Other strategies\n```\n\n```elixir\ndefmodule MultiProviderAuth do\n  @spec authorize_url(atom()) :: {:ok, map()} | {:error, term()}\n  def authorize_url(provider) do\n    config = config!(provider)\n\n    config[:strategy].authorize_url()\n  end\n\n  @spec callback(atom(), map(), map()) :: {:ok, map()} | {:error, term()}\n  def callback(provider, params, session_params) do\n    config = config!(provider)\n\n    config\n    |> Keyword.put(:session_params, session_params)\n    |> config[:strategy].callback(params)\n  end\n\n  defp config!(provider) do\n    config =\n      Application.get_env(:my_app, :strategies)[provider] ||\n        raise \"No provider configuration for #{provider}\"\n    \n    Keyword.put(config, :redirect_uri, \"http://localhost:4000/oauth/#{provider}/callback\")\n  end\nend\n```","ref":"Assent.html#module-multi-provider"},{"type":"module","title":"Custom provider - Assent","doc":"You can create custom strategies. Here's an example of an OAuth 2.0 implementation using `Assent.Strategy.OAuth2.Base`:\n\n```elixir\ndefmodule TestProvider do\n  use Assent.Strategy.OAuth2.Base\n\n  @impl true\n  def default_config(_config) do\n    [\n      # `:base_url` will be used for any paths below\n      base_url: \"http://localhost:4000/api/v1\",\n       # Definining an absolute URI overrides the `:base_url`\n      authorize_url: \"http://localhost:4000/oauth/authorize\",\n      token_url: \"/oauth/access_token\",\n      user_url: \"/user\",\n      authorization_params: [scope: \"email profile\"],\n      auth_method: :client_secret_post\n    ]\n  end\n\n  @impl true\n  def normalize(_config, user) do\n    {:ok,\n      # Conformed to https://openid.net/specs/openid-connect-core-1_0.html#rfc.section.5.1\n      %{\n        \"sub\"      => user[\"sub\"],\n        \"name\"     => user[\"name\"],\n        \"nickname\" => user[\"username\"],\n        \"email\"    => user[\"email\"]\n      # },\n      # # Provider specific data not part of the standard claims spec\n      # %{\n      #   \"http://localhost:4000/bio\" => user[\"bio\"]\n      }\n    }\n  end\nend\n```\n\nThe normalized user map should conform to the [OpenID Connect Core 1.0 Standard Claims spec](https://openid.net/specs/openid-connect-core-1_0.html#rfc.section.5.1), and should return either `{:ok, userinfo_claims}` or `{:ok, userinfo_claims, additional}`. Any keys defined in the userinfo claims that aren't part of the specs will not be included in the user map. Instead, they should be set in the additional data that will then be merged on top of the userinfo claims excluding any keys that have already been set.\n\nYou can use any of the `Assent.Strategy.OAuth2.Base`, `Assent.Strategy.OAuth.Base`, and `Assent.Strategy.OIDC.Base` macros to set up the strategy.\n\nIf you need more control over the strategy than what the macros give you, you can implement your provider using the `Assent.Strategy` behaviour:\n\n```elixir\ndefmodule TestProvider do\n  @behaviour Assent.Strategy\n\n  alias Assent.Strategy, as: Helpers\n\n  @impl Assent.Strategy\n  def authorize_url(config) do\n    # Generate redirect URL\n\n    {:ok, %{url: url}}\n  end\n\n  @impl Assent.Strategy\n  def callback(config, params) do\n    # Fetch user data\n\n    user = Helpers.normalize_userinfo(userinfo)\n\n    {:ok, %{user: user}}\n  end\nend\n```","ref":"Assent.html#module-custom-provider"},{"type":"module","title":"HTTP Client - Assent","doc":"Assent supports [`Req`](https://github.com/wojtekmach/req), [`Finch`](https://github.com/sneako/finch), and [`:httpc`](https://www.erlang.org/doc/man/httpc.html) out of the box. The `Req` HTTP client adapter will be used by default if enabled, otherwise Erlang's `:httpc` adapter will be used.\n\nYou can explicitly set the HTTP client adapter in the configuration:\n\n```elixir\nconfig = [\n  client_id: \"REPLACE_WITH_CLIENT_ID\",\n  client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n  http_adapter: Assent.HTTPAdapter.Httpc\n]\n```\n\nOr globally in the config:\n\n```elixir\nconfig :assent, http_adapter: Assent.HTTPAdapter.Httpc\n```","ref":"Assent.html#module-http-client"},{"type":"module","title":"Req - Assent","doc":"`Req` doesn't require any additional configuration and will work out of the box:\n\n```elixir\ndefp deps do\n  [\n    # ...\n    {:req, \"~> 0.4\"}\n  ]\nend\n```\n\n### :httpc\n\nIf `Req` is not available, Erlangs built-in `:httpc` is used for requests. SSL verification is automatically enabled when `:certifi` and `:ssl_verify_fun` packages are available. `:httpc` only supports HTTP/1.1.\n\n```elixir\ndefp deps do\n  [\n    # ...\n    # Required for SSL validation if using the `:httpc` adapter\n    {:certifi, \"~> 2.4\"},\n    {:ssl_verify_fun, \"~> 1.1\"}\n  ]\nend\n```\n\nYou must include `:inets` to `:extra_applications` to include `:httpc` in your release.","ref":"Assent.html#module-req"},{"type":"module","title":"Finch - Assent","doc":"`Finch` will require a supervisor in your application.\n\nUpdate `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    # ...\n    {:finch, \"~> 0.16\"}\n  ]\nend\n```\n\nEnsure you start the Finch supervisor in your application, and set `:http_adapter` in your provider configuration using your connection pool:\n\n```elixir\nconfig = [\n  client_id: \"REPLACE_WITH_CLIENT_ID\",\n  client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n  http_adapter: {Assent.HTTPAdapter.Finch, supervisor: MyFinch}\n]\n```","ref":"Assent.html#module-finch"},{"type":"module","title":"JWT Adapter - Assent","doc":"By default the built-in `Assent.JWTAdapter.AssentJWT` is used for JWT parsing, but you can change it to any third-party library with a custom `Assent.JWTAdapter`. A [JOSE](https://github.com/potatosalad/erlang-jose) adapter `Assent.JWTAdapter.JOSE` is included.\n\nTo use JOSE, update `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    # ...\n    {:jose, \"~> 1.8\"}\n  ]\nend\n```\n\nAnd pass the `:jwt_adapter` with your provider configuration:\n\n```elixir\nconfig = [\n  client_id: \"REPLACE_WITH_CLIENT_ID\",\n  client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n  jwt_adapter: Assent.JWTAdapter.JOSE\n]\n```\n\nOr globally in the config:\n\n```elixir\nconfig :assent, jwt_adapter: Assent.JWTAdapter.JOSE\n```","ref":"Assent.html#module-jwt-adapter"},{"type":"function","title":"Assent.fetch_config/2","doc":"Fetches the key value from the configuration.\n\nReturns a `Assent.MissingConfigError` if the key is not found.","ref":"Assent.html#fetch_config/2"},{"type":"function","title":"Assent.fetch_param/2","doc":"Fetches the key value from the params.\n\nReturns a `Assent.MissingParamError` if the key is not found.","ref":"Assent.html#fetch_param/2"},{"type":"function","title":"Assent.json_library/1","doc":"Fetches the JSON library in config.\n\nIf not found in provided config, this will attempt to load the JSON library\nfrom global application environment for `:assent`. Defaults to\n`JSON`.","ref":"Assent.html#json_library/1"},{"type":"module","title":"Assent.Strategy.OAuth","doc":"OAuth 1.0a strategy.\n\n`authorize_url/1` returns a map with a `:session_params` and `:url` key. The\n`:session_params` key carries a `:oauth_token_secret` value for the request.","ref":"Assent.Strategy.OAuth.html"},{"type":"module","title":"Configuration - Assent.Strategy.OAuth","doc":"- `:consumer_key` - The OAuth consumer key, required\n  - `:base_url` - The base URL of the OAuth server, required\n  - `:signature_method` -  The signature method, optional, defaults to\n    `:hmac_sha1`. The value may be one of the following:\n\n    - `:hmac_sha1` - Generates signature with HMAC-SHA1\n    - `:rsa_sha1` - Generates signature with RSA-SHA1\n    - `:plaintext` - Doesn't generate signature\n  - `:consumer_secret` - The OAuth consumer secret, required if\n    `:signature_method` is either `:hmac_sha1` or `:plaintext`\n  - `:private_key_path` - The path for the private key, required if\n    `:signature_method` is `:rsa_sha1` and `:private_key` hasn't been set\n  - `:private_key` - The private key content that can be defined instead of\n    `:private_key_path`, required if `:signature_method` is `:rsa_sha1` and\n    `:private_key_path` hasn't been set","ref":"Assent.Strategy.OAuth.html#module-configuration"},{"type":"module","title":"Examples - Assent.Strategy.OAuth","doc":"defmodule OAuth do\n      import Plug.Conn\n\n      alias Assent.Strategy.OAuth\n\n      defp config do\n        [\n          consumer_key: Application.fetch_env!(:my_app, :oauth, :consumer_key),\n          consumer_secret: Application.fetch_env!(:my_app, :oauth, :consumer_secret),\n          base_url: \"https://auth.example.com\",\n          authorization_params: [scope: \"user:read user:write\"],\n          user_url: \"https://example.com/api/user\",\n          redirect_uri: \"http://localhost:4000/auth/callback\"\n        ]\n      end\n\n      def request(conn) do\n        config()\n        |> OAuth.authorize_url()\n        |> case do\n          {:ok, %{url: url, session_params: session_params}} ->\n            conn\n            |> put_session(:session_params, session_params)\n            |> put_resp_header(\"location\", url)\n            |> send_resp(302, \"\")\n\n          {:error, _error} ->\n            send_resp(conn, 500, \"Failed authorization\")\n        end\n      end\n\n      def callback(conn) do\n        %{params: params} = fetch_query_params(conn)\n        session_params = get_session(conn, :session_params)\n        conn = delete_session(conn, :session_params)\n\n        config()\n        |> Keyword.put(:session_params, session_params)\n        |> OAuth.callback(params)\n        |> case do\n          {:ok, %{user: user, token: token}} ->\n            conn\n            |> put_session(:user, user)\n            |> put_session(:token, token)\n            |> put_resp_header(\"location\", \"/\")\n            |> send_resp(302, \"\")\n\n          {:error, _error} ->\n            send_resp(conn, 500, \"Failed authorization\")\n        end\n      end\n    end","ref":"Assent.Strategy.OAuth.html#module-examples"},{"type":"function","title":"Assent.Strategy.OAuth.authorize_url/1","doc":"Generate authorization URL for request phase.","ref":"Assent.Strategy.OAuth.html#authorize_url/1"},{"type":"function","title":"Options - Assent.Strategy.OAuth.authorize_url/1","doc":"- `:redirect_uri` - The URI that the server redirects the user to after\n    authentication, required\n  - `:request_token_url` - The path or URL to fetch the token from, optional,\n    defaults to `/oauth/request_token`\n  - `:authorize_url` - The path or URL for the OAuth server to redirect users\n    to, defaults to `/oauth/authenticate`\n  - `:authorization_params` - The authorization parameters, defaults to `[]`","ref":"Assent.Strategy.OAuth.html#authorize_url/1-options"},{"type":"function","title":"Assent.Strategy.OAuth.callback/3","doc":"Callback phase for generating access token and fetch user data.","ref":"Assent.Strategy.OAuth.html#callback/3"},{"type":"function","title":"Options - Assent.Strategy.OAuth.callback/3","doc":"- `:access_token_url` - The path or URL to fetch the access token from,\n    optional, defaults to `/oauth/access_token`\n  - `:user_url` - The path or URL to fetch user data, required\n  - `:session_params` - The session parameters that was returned from\n    `authorize_url/1`, optional","ref":"Assent.Strategy.OAuth.html#callback/3-options"},{"type":"type","title":"Assent.Strategy.OAuth.on_authorize_url/0","doc":"","ref":"Assent.Strategy.OAuth.html#t:on_authorize_url/0"},{"type":"type","title":"Assent.Strategy.OAuth.on_callback/0","doc":"","ref":"Assent.Strategy.OAuth.html#t:on_callback/0"},{"type":"function","title":"Assent.Strategy.OAuth.request/6","doc":"Performs a signed HTTP request to the API using the oauth token.","ref":"Assent.Strategy.OAuth.html#request/6"},{"type":"type","title":"Assent.Strategy.OAuth.session_params/0","doc":"","ref":"Assent.Strategy.OAuth.html#t:session_params/0"},{"type":"module","title":"Assent.Strategy.OAuth2","doc":"OAuth 2.0 strategy.\n\nThis strategy only supports the Authorization Code flow per\n[RFC 6749](https://tools.ietf.org/html/rfc6749#section-1.3.1).\n\n`authorize_url/1` returns a map with a `:url` and `:session_params` key. The\n`:session_params` should be stored and passed back into `callback/3` as part\nof config when the user returns. The `:session_params` carries a `:state`\nvalue for the request [to prevent\nCSRF](https://tools.ietf.org/html/rfc6749#section-4.1.1). If `:code_verifier`\nis set to true, the `:session_params` will also carry PKCE [code verification\nparameters](https://datatracker.ietf.org/doc/html/rfc7636#section-4).\n\nThis library also supports JWT tokens for client authentication as per\n[RFC 7523](https://tools.ietf.org/html/rfc7523).","ref":"Assent.Strategy.OAuth2.html"},{"type":"module","title":"Configuration - Assent.Strategy.OAuth2","doc":"- `:client_id` - The OAuth2 client id, required\n  - `:base_url` - The base URL of the OAuth2 server, required\n  - `:auth_method` - The authentication strategy used, optional. If not set,\n    no authentication will be used during the access token request (e.g.\n    public clients). The value may be one of the following:\n\n    - `:client_secret_basic` - Authenticate with basic authorization header\n    - `:client_secret_post` - Authenticate with post params\n    - `:client_secret_jwt` - Authenticate with JWT using `:client_secret` as\n      secret\n    - `:private_key_jwt` - Authenticate with JWT using `:private_key_path` or\n      `:private_key` as secret\n  - `:client_secret` - The OAuth2 client secret, required if `:auth_method`\n    is `:client_secret_basic`, `:client_secret_post`, or `:client_secret_jwt`\n  - `:private_key_id` - The private key ID, required if `:auth_method` is\n    `:private_key_jwt`\n  - `:private_key_path` - The path for the private key, required if\n    `:auth_method` is `:private_key_jwt` and `:private_key` hasn't been set\n  - `:private_key` - The private key content that can be defined instead of\n    `:private_key_path`, required if `:auth_method` is `:private_key_jwt` and\n    `:private_key_path` hasn't been set\n  - `:jwt_algorithm` - The algorithm to use for JWT signing, optional,\n    defaults to `HS256` for `:client_secret_jwt` and `RS256` for\n    `:private_key_jwt`\n  - `:state` - A boolean or a string with the value of the state, optional,\n    defaults to `true`. When set to `true` a random 32 byte long url safe\n    string is generated. When set to `false` state will not be verified.\n  - `:code_verifier` - Boolean to generate and use a random 128 byte long\n    url safe code verifier for PKCE flow, optional, defaults to `false`. When\n    set to `true` the session params will contain `:code_verifier`,\n    `:code_challenge`, and `:code_challenge_method` params.","ref":"Assent.Strategy.OAuth2.html#module-configuration"},{"type":"module","title":"Examples - Assent.Strategy.OAuth2","doc":"defmodule OAuth2 do\n      import Plug.Conn\n\n      alias Assent.Strategy.OAuth2\n\n      defp config do\n        [\n          client_id: Application.fetch_env!(:my_app, :oidc, :client_id),\n          client_secret: Application.fetch_env!(:my_app, :oidc, :client_secret),\n          auth_method: :client_secret_post,\n          base_url: \"https://auth.example.com\",\n          authorization_params: [scope: \"user:read user:write\"],\n          user_url: \"https://example.com/api/user\",\n          redirect_uri: \"http://localhost:4000/auth/callback\"\n        ]\n      end\n\n      def request(conn) do\n        config()\n        |> OAuth2.authorize_url()\n        |> case do\n          {:ok, %{url: url, session_params: session_params}} ->\n            conn\n            |> put_session(:session_params, session_params)\n            |> put_resp_header(\"location\", url)\n            |> send_resp(302, \"\")\n\n          {:error, _error} ->\n            send_resp(conn, 500, \"Failed authorization\")\n        end\n      end\n\n      def callback(conn) do\n        %{params: params} = fetch_query_params(conn)\n        session_params = get_session(conn, :session_params)\n        conn = delete_session(conn, :session_params)\n\n        config()\n        |> Keyword.put(:session_params, session_params)\n        |> OAuth2.callback(params)\n        |> case do\n          {:ok, %{user: user, token: token}} ->\n            conn\n            |> put_session(:user, user)\n            |> put_session(:token, token)\n            |> put_resp_header(\"location\", \"/\")\n            |> send_resp(302, \"\")\n\n          {:error, _error} ->\n            send_resp(conn, 500, \"Failed authorization\")\n        end\n      end\n    end","ref":"Assent.Strategy.OAuth2.html#module-examples"},{"type":"function","title":"Assent.Strategy.OAuth2.authorize_url/1","doc":"Generate authorization URL for request phase.","ref":"Assent.Strategy.OAuth2.html#authorize_url/1"},{"type":"function","title":"Options - Assent.Strategy.OAuth2.authorize_url/1","doc":"- `:redirect_uri` - The URI that the server redirects the user to after\n    authentication, required\n  - `:authorize_url` - The path or URL for the OAuth2 server to redirect\n    users to, defaults to `/oauth/authorize`\n  - `:authorization_params` - The authorization parameters, defaults to `[]`","ref":"Assent.Strategy.OAuth2.html#authorize_url/1-options"},{"type":"function","title":"Assent.Strategy.OAuth2.callback/3","doc":"Callback phase for generating access token with authorization code and fetch\nuser data. Returns a map with access token in `:token` and user data in\n`:user`.","ref":"Assent.Strategy.OAuth2.html#callback/3"},{"type":"function","title":"Options - Assent.Strategy.OAuth2.callback/3","doc":"- `:token_url` - The path or URL to fetch the token from, optional,\n    defaults to `/oauth/token`\n  - `:user_url` - The path or URL to fetch user data, required\n  - `:session_params` - The session parameters that was returned from\n    `authorize_url/1`, optional","ref":"Assent.Strategy.OAuth2.html#callback/3-options"},{"type":"function","title":"Assent.Strategy.OAuth2.fetch_user/4","doc":"Fetch user data with the access token.\n\nUses `request/6` to fetch the user data.","ref":"Assent.Strategy.OAuth2.html#fetch_user/4"},{"type":"function","title":"Assent.Strategy.OAuth2.grant_access_token/3","doc":"Grants an access token.","ref":"Assent.Strategy.OAuth2.html#grant_access_token/3"},{"type":"type","title":"Assent.Strategy.OAuth2.on_authorize_url/0","doc":"","ref":"Assent.Strategy.OAuth2.html#t:on_authorize_url/0"},{"type":"type","title":"Assent.Strategy.OAuth2.on_callback/0","doc":"","ref":"Assent.Strategy.OAuth2.html#t:on_callback/0"},{"type":"function","title":"Assent.Strategy.OAuth2.refresh_access_token/3","doc":"Refreshes the access token.","ref":"Assent.Strategy.OAuth2.html#refresh_access_token/3"},{"type":"function","title":"Assent.Strategy.OAuth2.request/6","doc":"Performs a HTTP request to the API using the access token.","ref":"Assent.Strategy.OAuth2.html#request/6"},{"type":"type","title":"Assent.Strategy.OAuth2.session_params/0","doc":"","ref":"Assent.Strategy.OAuth2.html#t:session_params/0"},{"type":"module","title":"Assent.Strategy.OIDC","doc":"OpenID Connect strategy.\n\nThis is built upon the `Assent.Strategy.OAuth2` strategy with added OpenID\nConnect capabilities.","ref":"Assent.Strategy.OIDC.html"},{"type":"module","title":"Configuration - Assent.Strategy.OIDC","doc":"- `:client_id` - The client id, required\n  - `:base_url` - The OIDC issuer, required\n  - `:openid_configuration_uri` - The URI for OpenID Provider, optional,\n    defaults to `/.well-known/openid-configuration`\n  - `:client_authentication_method` - The Client Authentication method to\n    use, optional, defaults to `client_secret_basic`.  The value may be one\n    of the following:\n\n    - `none` - No client authentication, used with public clients\n    - `client_secret_basic` - Authenticate with basic authorization header\n    - `client_secret_post` - Authenticate with post params\n    - `client_secret_jwt` - Authenticate with JWT using `:client_secret` as\n      secret\n    - `private_key_jwt` - Authenticate with JWT using `:private_key_path` or\n      `:private_key` as secret\n  - `:client_secret` - The client secret, required if\n    `:client_authentication_method` is `client_secret_basic`,\n    `:client_secret_post`, or `:client_secret_jwt`\n  - `:openid_configuration` - The OpenID configuration, optional, the\n    configuration will be fetched from `:openid_configuration_uri` if this is\n    not defined\n  - `:id_token_signed_response_alg` - The `id_token_signed_response_alg`\n    parameter sent by the Client during Registration, defaults to `RS256`\n  - `:id_token_ttl_seconds` - The number of seconds from `iat` that an ID\n    Token will be considered valid, optional, defaults to nil\n  - `:nonce` - The nonce to use for authorization request, optional, MUST be\n    session based and unguessable\n  - `:trusted_audiences` - A list of audiences that are trusted, optional.\n\nSee `Assent.Strategy.OAuth2` for more configuration options.","ref":"Assent.Strategy.OIDC.html#module-configuration"},{"type":"module","title":"Examples - Assent.Strategy.OIDC","doc":"defmodule OIDCAuth do\n      import Plug.Conn\n\n      alias Assent.Strategy.OIDC\n\n      defp config do\n        [\n          client_id: Application.fetch_env!(:my_app, :oidc, :client_id),\n          client_secret: Application.fetch_env!(:my_app, :oidc, :client_secret),\n          base_url: \"https://server.example.com\",\n          authorization_params: [scope: \"user:read user:write\"],\n          redirect_uri: \"http://localhost:4000/auth/callback\"\n        ]\n      end\n\n      def request(conn) do\n        config()\n        |> OIDC.authorize_url()\n        |> case do\n          {:ok, %{url: url, session_params: session_params}} ->\n            conn\n            |> put_session(:session_params, session_params)\n            |> put_resp_header(\"location\", url)\n            |> send_resp(302, \"\")\n\n          {:error, _error} ->\n            send_resp(conn, 500, \"Failed authorization\")\n        end\n      end\n\n      def callback(conn) do\n        %{params: params} = fetch_query_params(conn)\n        session_params = get_session(conn, :session_params)\n        conn = delete_session(conn, :session_params)\n\n        config()\n        |> Keyword.put(:session_params, session_params)\n        |> OIDC.callback(params)\n        |> case do\n          {:ok, %{user: user, token: token}} ->\n            conn\n            |> put_session(:user, user)\n            |> put_session(:token, token)\n            |> put_resp_header(\"location\", \"/\")\n            |> send_resp(302, \"\")\n\n          {:error, _error} ->\n            send_resp(conn, 500, \"Failed authorization\")\n        end\n      end\n    end","ref":"Assent.Strategy.OIDC.html#module-examples"},{"type":"module","title":"Nonce - Assent.Strategy.OIDC","doc":"`:nonce` can be set in the provider config. The `:nonce` will be returned in\nthe `:session_params` along with `:state`. You can use this to store the value\nin the current session e.g. a httpOnly session cookie.\n\nA random value generator can look like this:\n\n    16\n    |> :crypto.strong_rand_bytes()\n    |> Base.encode64(padding: false)\n\nAssent will dynamically generate one for the session if `:nonce` is set to\n`true`.\n\nSee `Assent.Strategy.OIDC.authorize_url/1` for more.","ref":"Assent.Strategy.OIDC.html#module-nonce"},{"type":"function","title":"Assent.Strategy.OIDC.authorize_url/1","doc":"Generates an authorization URL for request phase.\n\nThe authorization url will be fetched from the OpenID configuration URI.\n\n`openid` will automatically be added to the `:scope` in\n`:authorization_params`, unless `:openid_default_scope` has been set.\n\nAdd `:nonce` to the config to pass it with the authorization request. The\nnonce will be returned in `:session_params`. The nonce MUST be session based\nand unguessable. A cryptographic hash of a cryptographically random value\ncould be stored in a httpOnly session cookie.\n\nSee `Assent.Strategy.OAuth2.authorize_url/1` for more.","ref":"Assent.Strategy.OIDC.html#authorize_url/1"},{"type":"function","title":"Assent.Strategy.OIDC.callback/3","doc":"Callback phase for generating access token and fetch user data.\n\nThe token url will be fetched from the OpenID configuration URI.\n\nIf the returned ID Token is signed with a symmetric key, `:client_secret`\nwill be required and used to verify the ID Token. If it was signed with a\nprivate key, the appropriate public key will be fetched from the `jwks_uri`\nsetting in the OpenID configuration to verify the ID Token.\n\nThe ID Token will be validated per\n[OpenID Connect Core 1.0 rules](https://openid.net/specs/openid-connect-core-1_0.html#IDTokenValidation).\n\nSee `Assent.Strategy.OAuth2.callback/3` for more.","ref":"Assent.Strategy.OIDC.html#callback/3"},{"type":"function","title":"Assent.Strategy.OIDC.fetch_user/2","doc":"Fetches user params from ID token.\n\nThe ID Token is validated, and the claims is returned as the user params.\nUse `fetch_userinfo/2` to fetch the claims from the `userinfo` endpoint.","ref":"Assent.Strategy.OIDC.html#fetch_user/2"},{"type":"function","title":"Assent.Strategy.OIDC.fetch_userinfo/2","doc":"Fetches claims from userinfo endpoint.\n\nThe userinfo will be fetched from the `userinfo_endpoint` OpenID\nconfiguration.\n\nThe returned claims will be validated against the `id_token` verifying that\n`sub` is equal.","ref":"Assent.Strategy.OIDC.html#fetch_userinfo/2"},{"type":"type","title":"Assent.Strategy.OIDC.on_authorize_url/0","doc":"","ref":"Assent.Strategy.OIDC.html#t:on_authorize_url/0"},{"type":"type","title":"Assent.Strategy.OIDC.on_callback/0","doc":"","ref":"Assent.Strategy.OIDC.html#t:on_callback/0"},{"type":"type","title":"Assent.Strategy.OIDC.session_params/0","doc":"","ref":"Assent.Strategy.OIDC.html#t:session_params/0"},{"type":"function","title":"Assent.Strategy.OIDC.validate_id_token/2","doc":"Validates the ID token.\n\nThe OpenID configuration will be dynamically fetched if not set in the\nconfig.\n\nThe ID Token will be validated per\n[OpenID Connect Core 1.0 rules](https://openid.net/specs/openid-connect-core-1_0.html#IDTokenValidation).","ref":"Assent.Strategy.OIDC.html#validate_id_token/2"},{"type":"behaviour","title":"Assent.Strategy","doc":"Used for creating strategies.","ref":"Assent.Strategy.html"},{"type":"behaviour","title":"Usage - Assent.Strategy","doc":"Set up `my_strategy.ex` the following way:\n\n    defmodule MyStrategy do\n      @behaviour Assent.Strategy\n\n      alias Assent.Strategy, as: Helpers\n\n      @impl Assent.Strategy\n      def authorize_url(config) do\n        # Generate redirect URL\n\n        {:ok, %{url: url, ...}}\n      end\n\n      @impl Assent.Strategy\n      def callback(config, params) do\n        # Fetch user data\n\n        user = Helpers.normalize_userinfo(userinfo)\n\n        {:ok, %{user: user, ...}}\n      end\n    end","ref":"Assent.Strategy.html#module-usage"},{"type":"callback","title":"Assent.Strategy.authorize_url/1","doc":"","ref":"Assent.Strategy.html#c:authorize_url/1"},{"type":"callback","title":"Assent.Strategy.callback/2","doc":"","ref":"Assent.Strategy.html#c:callback/2"},{"type":"function","title":"Assent.Strategy.decode_json/2","doc":"Decode a JSON string.","ref":"Assent.Strategy.html#decode_json/2"},{"type":"function","title":"Options - Assent.Strategy.decode_json/2","doc":"- `:json_library` - The JSON library to use, see\n  `Assent.json_library/1`","ref":"Assent.Strategy.html#decode_json/2-options"},{"type":"function","title":"Assent.Strategy.http_request/5","doc":"Makes a HTTP request.\n\nSee `Assent.HTTPAdapter.request/5`.","ref":"Assent.Strategy.html#http_request/5"},{"type":"function","title":"Assent.Strategy.normalize_userinfo/2","doc":"Normalize API user request response into standard claims.\n\nThe function will cast values to adhere to the following types:\n\n```\n%{\n  \"address\" => %{\n    \"country\" => :binary,\n    \"formatted\" => :binary,\n    \"locality\" => :binary,\n    \"postal_code\" => :binary,\n    \"region\" => :binary,\n    \"street_address\" => :binary\n  },\n  \"birthdate\" => :binary,\n  \"email\" => :binary,\n  \"email_verified\" => :boolean,\n  \"family_name\" => :binary,\n  \"gender\" => :binary,\n  \"given_name\" => :binary,\n  \"locale\" => :binary,\n  \"middle_name\" => :binary,\n  \"name\" => :binary,\n  \"nickname\" => :binary,\n  \"phone_number\" => :binary,\n  \"phone_number_verified\" => :boolean,\n  \"picture\" => :binary,\n  \"preferred_username\" => :binary,\n  \"profile\" => :binary,\n  \"sub\" => :binary,\n  \"updated_at\" => :integer,\n  \"website\" => :binary,\n  \"zoneinfo\" => :binary\n}\n```\n\nReturns an `Assent.CastClaimsError` if any of the above types can't be casted.\n\nBased on https://openid.net/specs/openid-connect-core-1_0.html#rfc.section.5.1","ref":"Assent.Strategy.html#normalize_userinfo/2"},{"type":"function","title":"Assent.Strategy.sign_jwt/4","doc":"Signs a JSON Web Token.\n\nSee `Assent.JWTAdapter.sign/3` for options.","ref":"Assent.Strategy.html#sign_jwt/4"},{"type":"function","title":"Assent.Strategy.to_url/3","doc":"Generates a URL.","ref":"Assent.Strategy.html#to_url/3"},{"type":"function","title":"Assent.Strategy.verify_jwt/3","doc":"Verifies a JSON Web Token.\n\nSee `Assent.JWTAdapter.verify/3` for options.","ref":"Assent.Strategy.html#verify_jwt/3"},{"type":"behaviour","title":"Assent.Strategy.OAuth.Base","doc":"OAuth 1.0 strategy base.","ref":"Assent.Strategy.OAuth.Base.html"},{"type":"behaviour","title":"Usage - Assent.Strategy.OAuth.Base","doc":"defmodule MyApp.MyOAuthStratey do\n      use Assent.Strategy.OAuth\n\n      @impl true\n      def default_config(_config) do\n        [\n          base_url: \"https://api.example.com\",\n          authorize_url: \"/authorization/new\",\n          access_token_url: \"/authorization/access_token\"\n          request_token_url: \"/authorization/request_token\",\n          user_url: \"/authorization.json\",\n          authorization_params: [scope: \"default\"]\n        ]\n      end\n\n      @impl true\n      def normalize(_config, user) do\n        {:ok,\n          # Conformed to https://openid.net/specs/openid-connect-core-1_0.html#rfc.section.5.1\n          %{\n            \"sub\"   => user[\"id\"],\n            \"name\"  => user[\"name\"],\n            \"email\" => user[\"email\"]\n          # },\n          # # Provider specific data not part of the standard claims spec\n          # %{\n          #  \"https://example.com/bio\" => user[\"bio\"]\n          }\n        }\n      end\n    end","ref":"Assent.Strategy.OAuth.Base.html#module-usage"},{"type":"function","title":"Assent.Strategy.OAuth.Base.authorize_url/2","doc":"","ref":"Assent.Strategy.OAuth.Base.html#authorize_url/2"},{"type":"function","title":"Assent.Strategy.OAuth.Base.callback/3","doc":"","ref":"Assent.Strategy.OAuth.Base.html#callback/3"},{"type":"callback","title":"Assent.Strategy.OAuth.Base.default_config/1","doc":"","ref":"Assent.Strategy.OAuth.Base.html#c:default_config/1"},{"type":"callback","title":"Assent.Strategy.OAuth.Base.fetch_user/2","doc":"","ref":"Assent.Strategy.OAuth.Base.html#c:fetch_user/2"},{"type":"callback","title":"Assent.Strategy.OAuth.Base.normalize/2","doc":"","ref":"Assent.Strategy.OAuth.Base.html#c:normalize/2"},{"type":"behaviour","title":"Assent.Strategy.OAuth2.Base","doc":"OAuth 2.0 strategy base.","ref":"Assent.Strategy.OAuth2.Base.html"},{"type":"behaviour","title":"Usage - Assent.Strategy.OAuth2.Base","doc":"defmodule MyApp.MyOAuth2Strategy do\n      use Assent.Strategy.OAuth2.Base\n\n      def default_config(_config) do\n        [\n          base_url: \"https://api.example.com\",\n          user_url: \"/authorization.json\"\n        ]\n      end\n\n      @impl true\n      def normalize(_config, user) do\n        {:ok,\n          # Conformed to https://openid.net/specs/openid-connect-core-1_0.html#rfc.section.5.1\n          %{\n            \"sub\"   => user[\"id\"],\n            \"name\"  => user[\"name\"],\n            \"email\" => user[\"email\"]\n          # },\n          # # Provider specific data not part of the standard claims spec\n          # %{\n          #  \"https://example.com/bio\" => user[\"bio\"]\n          }\n        }\n      end\n    end","ref":"Assent.Strategy.OAuth2.Base.html#module-usage"},{"type":"function","title":"Assent.Strategy.OAuth2.Base.authorize_url/2","doc":"","ref":"Assent.Strategy.OAuth2.Base.html#authorize_url/2"},{"type":"function","title":"Assent.Strategy.OAuth2.Base.callback/3","doc":"","ref":"Assent.Strategy.OAuth2.Base.html#callback/3"},{"type":"callback","title":"Assent.Strategy.OAuth2.Base.default_config/1","doc":"","ref":"Assent.Strategy.OAuth2.Base.html#c:default_config/1"},{"type":"callback","title":"Assent.Strategy.OAuth2.Base.fetch_user/2","doc":"","ref":"Assent.Strategy.OAuth2.Base.html#c:fetch_user/2"},{"type":"callback","title":"Assent.Strategy.OAuth2.Base.normalize/2","doc":"","ref":"Assent.Strategy.OAuth2.Base.html#c:normalize/2"},{"type":"behaviour","title":"Assent.Strategy.OIDC.Base","doc":"OIDC OAuth 2.0 strategy base.","ref":"Assent.Strategy.OIDC.Base.html"},{"type":"behaviour","title":"Usage - Assent.Strategy.OIDC.Base","doc":"defmodule MyApp.MyOIDCStrategy do\n      use Assent.Strategy.OIDC.Base\n\n      def default_config(_config) do\n        [\n          base_url: \"https://oidc.example.com\"\n        ]\n      end\n\n      def normalize(_config, user), do: {:ok, user}\n    end","ref":"Assent.Strategy.OIDC.Base.html#module-usage"},{"type":"function","title":"Assent.Strategy.OIDC.Base.authorize_url/2","doc":"","ref":"Assent.Strategy.OIDC.Base.html#authorize_url/2"},{"type":"function","title":"Assent.Strategy.OIDC.Base.callback/3","doc":"","ref":"Assent.Strategy.OIDC.Base.html#callback/3"},{"type":"callback","title":"Assent.Strategy.OIDC.Base.default_config/1","doc":"","ref":"Assent.Strategy.OIDC.Base.html#c:default_config/1"},{"type":"callback","title":"Assent.Strategy.OIDC.Base.fetch_user/2","doc":"","ref":"Assent.Strategy.OIDC.Base.html#c:fetch_user/2"},{"type":"callback","title":"Assent.Strategy.OIDC.Base.normalize/2","doc":"","ref":"Assent.Strategy.OIDC.Base.html#c:normalize/2"},{"type":"module","title":"Assent.Strategy.Apple","doc":"Apple Sign In OAuth 2.0 strategy.\n\nYou'll need to collect the 10-char long Team ID, the Services ID, the 10-char\nKey ID and download the private key from the portal. Save the private key to\nan accessible folder, or alternatively set `:private_key` with the content of\nthe private key.","ref":"Assent.Strategy.Apple.html"},{"type":"module","title":"Usage - Assent.Strategy.Apple","doc":"config = [\n      client_id: \"REPLACE_WITH_SERVICES_ID\",\n      team_id: \"REPLACE_WITH_TEAM_ID\",\n      private_key_id: \"REPLACE_WITH_PRIVATE_KEY_ID\",\n      private_key_path: \"/path/to/private_key.p8\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]","ref":"Assent.Strategy.Apple.html#module-usage"},{"type":"module","title":"With JS SDK - Assent.Strategy.Apple","doc":"You can use the JS SDK instead of handling it through `auhorize_url/2`. All you\nhave to do is to set up you HTML page with the following way:\n\n     \n       \n           \n           \n           \n           \n       \n       \n            \n            \n       \n     \n\nYou can get the state by generating the session params using the\n`authorize_url/2`:\n\n    {:ok, %{session_params: session_params}} = Assent.Strategy.Apple.authorize_url(config)\n\nUse the `session_params[:state]` value for `[STATE]`. The callback phase\nwould be identical to how it's explained in the `Assent` docs.\n\nSee https://developer.apple.com/documentation/signinwithapplejs/configuring_your_webpage_for_sign_in_with_apple\nfor more.","ref":"Assent.Strategy.Apple.html#module-with-js-sdk"},{"type":"module","title":"Assent.Strategy.Auth0","doc":"Auth0 OpenID Connect strategy.","ref":"Assent.Strategy.Auth0.html"},{"type":"module","title":"Configuration - Assent.Strategy.Auth0","doc":"- `:base_url` - The Auth0 base URL, required","ref":"Assent.Strategy.Auth0.html#module-configuration"},{"type":"module","title":"Usage - Assent.Strategy.Auth0","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      base_url: \"https://my-domain.auth0.com\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Auth0.html#module-usage"},{"type":"module","title":"Assent.Strategy.AzureAD","doc":"Azure Active Directory OpenID Connect strategy.","ref":"Assent.Strategy.AzureAD.html"},{"type":"module","title":"Configuration - Assent.Strategy.AzureAD","doc":"- `:tenant_id` - The Azure tenant ID, optional, defaults to `common`\n\nSee `Assent.Strategy.OIDC` for more.","ref":"Assent.Strategy.AzureAD.html#module-configuration"},{"type":"module","title":"Usage - Assent.Strategy.AzureAD","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nA tenant id can be set to limit scope of users who can get access (defaults\nto \"common\"):\n\n    config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      tenant_id: \"REPLACE_WITH_TENANT_ID\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]","ref":"Assent.Strategy.AzureAD.html#module-usage"},{"type":"module","title":"Setting up Azure AD - Assent.Strategy.AzureAD","doc":"Login to Azure, and set up a new application:\nhttps://docs.microsoft.com/en-us/azure/active-directory/develop/quickstart-register-app\n\n* The callback URL should be added to \"Redirect URI\" for the application.\n* `client_id` is the \"Application ID\".","ref":"Assent.Strategy.AzureAD.html#module-setting-up-azure-ad"},{"type":"module","title":"Assent.Strategy.Basecamp","doc":"Basecamp OAuth 2.0 strategy.\n\nIn the normalized user response a `basecamp_accounts` field is included that\ncan be used to limit access to users belonging to a particular account.\n\nThe Basecamp user endpoint does not provide data on email verification, email\nis considered unverified.","ref":"Assent.Strategy.Basecamp.html"},{"type":"module","title":"Usage - Assent.Strategy.Basecamp","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Basecamp.html#module-usage"},{"type":"module","title":"Assent.Strategy.Bitbucket","doc":"Bitbucket Cloud OAuth 2.0 strategy.","ref":"Assent.Strategy.Bitbucket.html"},{"type":"module","title":"Configuration - Assent.Strategy.Bitbucket","doc":"- `:user_emails_url` - The API path or URL to fetch e-mails from, defaults to `/user/emails`\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Bitbucket.html#module-configuration"},{"type":"module","title":"Usage - Assent.Strategy.Bitbucket","doc":"config = [\n      client_id: \"REPLACE_WITH_CONSUMER_KEY\",\n      client_secret: \"REPLACE_WITH_CONSUMER_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]","ref":"Assent.Strategy.Bitbucket.html#module-usage"},{"type":"module","title":"Assent.Strategy.DigitalOcean","doc":"DigitalOcean OAuth 2.0 strategy.","ref":"Assent.Strategy.DigitalOcean.html"},{"type":"module","title":"Usage - Assent.Strategy.DigitalOcean","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.DigitalOcean.html#module-usage"},{"type":"module","title":"Assent.Strategy.Discord","doc":"Discord OAuth 2.0 strategy.","ref":"Assent.Strategy.Discord.html"},{"type":"module","title":"Usage - Assent.Strategy.Discord","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Discord.html#module-usage"},{"type":"module","title":"Assent.Strategy.Facebook","doc":"Facebook OAuth 2.0 strategy.\n\nThe Facebook user endpoint does not provide data on email verification, email\nis considered unverified. More here:\nhttps://developers.facebook.com/docs/facebook-login/multiple-providers#postfb1","ref":"Assent.Strategy.Facebook.html"},{"type":"module","title":"Configuration - Assent.Strategy.Facebook","doc":"- `:user_url_request_fields` - The fields for the resource, defaults to\n  `email,name,first_name,last_name,middle_name,link`\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Facebook.html#module-configuration"},{"type":"module","title":"Usage - Assent.Strategy.Facebook","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Facebook.html#module-usage"},{"type":"module","title":"With JS SDK - Assent.Strategy.Facebook","doc":"You can use the JS SDK instead of handling it through `auhorize_url/2`. All\nyou have to do is to set up you HTML page with the following way:\n\n     \n     \n     \n     \n\n     \n      function checkLoginState() {\n        FB.getLoginStatus(function(response) {\n          let signedRequest = response.authResponse.signedRequest\n          let encodedPayload = atob(signedRequest.split('.')[1])\n          let payload = JSON.parse(encodedPayload)\n\n          window.location.href = '<%= @redirect_uri %>?&code=' + encodeURI(payload.code)\n        });\n      }\n\n      window.fbAsyncInit = function() {\n        FB.init({\n          appId   : '[CLIENT_ID]',\n          cookie  : true, // required for server to pick up session\n          version : 'v6.0',\n          xfbml   : true\n        });\n      };\n     \n      \n\nIn the above, the signed request is decoded and the authorization code is\nfetched from it. The `@redirect_uri` is the callback URL.\n\nYou have to use an empty `redirect_uri` for the callback:\n\n    {:ok, %{user: user, token: token}} =\n      config\n      |> Keyword.put(:redirect_uri, \"\")\n      |> Assent.Strategy.Facebook.callback(params)","ref":"Assent.Strategy.Facebook.html#module-with-js-sdk"},{"type":"module","title":"Assent.Strategy.Github","doc":"Github OAuth 2.0 strategy.","ref":"Assent.Strategy.Github.html"},{"type":"module","title":"Configuration - Assent.Strategy.Github","doc":"- `:user_emails_url` - The API path or URL to fetch e-mails from, defaults to `/user/emails`\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Github.html#module-configuration"},{"type":"module","title":"Usage - Assent.Strategy.Github","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Github.html#module-usage"},{"type":"module","title":"Assent.Strategy.Gitlab","doc":"Gitlab OpenID Connect strategy.","ref":"Assent.Strategy.Gitlab.html"},{"type":"module","title":"Usage - Assent.Strategy.Gitlab","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Gitlab.html#module-usage"},{"type":"module","title":"Assent.Strategy.Google","doc":"Google OpenID Connect strategy.\n\nIn the normalized user response a `hd` (\"Hosted Domain\") field is\nincluded in user parameters and can be used to limit access to users\nbelonging to a particular hosted domain.","ref":"Assent.Strategy.Google.html"},{"type":"module","title":"Usage - Assent.Strategy.Google","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nTo get the refresh token, it's necessary to pass `access_type: \"offline\"` in\nthe authorization request:\n\n    config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      authorization_params: [\n        access_type: \"offline\",\n        scope: \"email profile\"\n      ]\n    ]\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Google.html#module-usage"},{"type":"module","title":"Assent.Strategy.Instagram","doc":"Instagram OAuth 2.0 strategy.\n\nThe Instagram user object does not provide data on email verification, email\nis considered unverified.","ref":"Assent.Strategy.Instagram.html"},{"type":"module","title":"Usage - Assent.Strategy.Instagram","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Instagram.html#module-usage"},{"type":"module","title":"Assent.Strategy.LINE","doc":"LINE Login OpenID Connect Strategy.","ref":"Assent.Strategy.LINE.html"},{"type":"module","title":"Usage - Assent.Strategy.LINE","doc":"config = [\n    client_id: \"REPLACE_WITH_CLIENT_ID\",\n    client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n    redirect_uri: \"http://localhost:4000/auth/callback\"\n  ]\n\nSee `Assent.Strategy.OIDC` for more.","ref":"Assent.Strategy.LINE.html#module-usage"},{"type":"module","title":"Assent.Strategy.Linkedin","doc":"Sign In with LinkedIn V2 OpenID Connect Strategy.\n\nYou'll need the `Sign In with LinkedIn v2` product enabled in your app. See the\n[LinkedIn integration guide](https://learn.microsoft.com/en-us/linkedin/consumer/integrations/self-serve/sign-in-with-linkedin-v2)\nfor more.","ref":"Assent.Strategy.Linkedin.html"},{"type":"module","title":"Usage - Assent.Strategy.Linkedin","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OIDC` for more.","ref":"Assent.Strategy.Linkedin.html#module-usage"},{"type":"module","title":"Assent.Strategy.Slack","doc":"Slack OAuth 2.0 OpenID Connect strategy.\n\nThe Slack user endpoint does not provide data on email verification, email is\nconsidered unverified.","ref":"Assent.Strategy.Slack.html"},{"type":"module","title":"Configuration - Assent.Strategy.Slack","doc":"- `:team_id` - The team id to restrict authorization for, optional, defaults to nil\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Slack.html#module-configuration"},{"type":"module","title":"Usage - Assent.Strategy.Slack","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nBy default, the user can decide what team should be used for authorization.\nIf you want to limit to a specific team, please pass a team id to the\nconfiguration:\n\n    config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      team_id: \"REPLACE_WITH_TEAM_ID\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nThis value will be not be used if you set a `authorization_params` key.\nInstead you should set `team: TEAM_ID` in the `authorization_params` keyword\nlist.","ref":"Assent.Strategy.Slack.html#module-usage"},{"type":"module","title":"Assent.Strategy.Spotify","doc":"Spotify OAuth 2.0 strategy.","ref":"Assent.Strategy.Spotify.html"},{"type":"module","title":"Usage - Assent.Strategy.Spotify","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Spotify.html#module-usage"},{"type":"module","title":"Assent.Strategy.Strava","doc":"Strava OAuth strategy.\n\nThe athlete endpoint, describing the currently authenticated user, does not\nreturn an email address - [changelog](https://developers.strava.com/docs/changelog/#january-17-2019).","ref":"Assent.Strategy.Strava.html"},{"type":"module","title":"Usage - Assent.Strategy.Strava","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Strava.html#module-usage"},{"type":"module","title":"Assent.Strategy.Stripe","doc":"Stripe Connect OAuth 2.0 strategy.","ref":"Assent.Strategy.Stripe.html"},{"type":"module","title":"Usage - Assent.Strategy.Stripe","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.Stripe.html#module-usage"},{"type":"module","title":"Connect Express - Assent.Strategy.Stripe","doc":"This strategy uses Connect Standard by default. To use Connect Express, the\nfollowing config can be used:\n\n\n    config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      authorize_url: \"https://connect.stripe.com/express/oauth/authorize\"\n      # authorization_params: [\n      #   stripe_user: [business_type: \"company\", email: \"user@example.com\"],\n      #   suggested_capabilities: [\"transfers\"]\n      # ]\n    ]","ref":"Assent.Strategy.Stripe.html#module-connect-express"},{"type":"module","title":"Assent.Strategy.Telegram","doc":"Telegram authorization strategy.\n\nSupports both\n[Telegram Login Widget](https://core.telegram.org/widgets/login),\nand  [Web Mini App](https://core.telegram.org/bots/webapps) authorizations.\n\nNote that using the `authorize_url/1` instead of the Telegram JavaScript\nembed script, will send the end-user to the `:return_to` path with a base64\nurl encoded JSON string in a URL fragment. This means that it can only be\naccessed client-side, so it must be parsed with JavaScript and resubmitted\nas query params:\n\n     \n      // Function to decode base64 without padding\n      function decodeBase64Url(base64Url) {\n        let base64 = base64Url.replace(/-/g, '+').replace(/_/g, '/');\n        switch (base64.length % 4) {\n          case 2: base64 += '=='; break;\n          case 3: base64 += '='; break;\n        }\n        return atob(base64);\n      }\n\n      // Parse the hash fragment\n      const hash = window.location.hash.substr(1);\n      const hashData = hash.split('=')\n\n      if (hashData[0] == \"tgAuthResult\") {\n        const data = JSON.parse(decodeBase64Url(hashData[1]))\n        const params = new URLSearchParams(data);\n\n        // Construct the new URL with query parameters\n        const newUrl = new URL(window.location.href.split('#')[0]);\n        params.forEach((value, key) => {\n          newUrl.searchParams.append(key, value);\n        });\n\n        // Redirect to the new URL\n        window.location.href = newUrl.toString();\n      }\n     \n\nNote that the returned user claims can vary widelty, and are depend on the\nauthorization channel and user settings.","ref":"Assent.Strategy.Telegram.html"},{"type":"module","title":"Configuration - Assent.Strategy.Telegram","doc":"- `:bot_token` - The telegram bot token, required\n  - `:authorization_channel` - The authorization channel, optional, defaults\n    to `:login_widget`, may be one of `:login_widget` or `:web_mini_app`\n  - `:origin` - The origin URL for `authorize_url/1`, required\n  - `:return_to` - The return URL for `authorize_url/1`, required","ref":"Assent.Strategy.Telegram.html#module-configuration"},{"type":"module","title":"Usage - Assent.Strategy.Telegram","doc":"","ref":"Assent.Strategy.Telegram.html#module-usage"},{"type":"module","title":"Login Widget - Assent.Strategy.Telegram","doc":"The JavaScript Widget can be implemented with:\n\n      \n\nConfiguration should have:\n\n    config = [\n      bot_token: \"YOUR_FULL_BOT_TOKEN\"\n    ]\n\nNote that if a user declines to authorize access, you have to handle it\nclient-side with JavaScript.","ref":"Assent.Strategy.Telegram.html#module-login-widget"},{"type":"module","title":"Web Mini App - Assent.Strategy.Telegram","doc":"config = [\n      bot_token: \"YOUR_FULL_BOT_TOKEN\",\n      authorization_channel: :web_mini_app\n    ]\n\nFor the Web Mini App authorization, the strategy expects the original\n`initData` query param to be passed in as-is.","ref":"Assent.Strategy.Telegram.html#module-web-mini-app"},{"type":"module","title":"Assent.Strategy.Twitch","doc":"Twitch OpenID Connect strategy.\n\nSee `Assent.Strategy.OIDC` for more.","ref":"Assent.Strategy.Twitch.html"},{"type":"module","title":"Assent.Strategy.Twitter","doc":"Twitter OAuth strategy.\n\nThe Twitter user endpoint only returns verified email, `email_verified` will\nalways be `true`.","ref":"Assent.Strategy.Twitter.html"},{"type":"module","title":"Usage - Assent.Strategy.Twitter","doc":"config = [\n      consumer_key: \"REPLACE_WITH_CONSUMER_KEY\",\n      consumer_secret: \"REPLACE_WITH_CONSUMER_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]\n\nSee `Assent.Strategy.OAuth` for more.","ref":"Assent.Strategy.Twitter.html#module-usage"},{"type":"module","title":"Assent.Strategy.VK","doc":"VK.com OAuth 2.0 strategy.\n\nThe VK token endpoint does not provide data on email verification, email is\nconsidered unverified.","ref":"Assent.Strategy.VK.html"},{"type":"module","title":"Configuration - Assent.Strategy.VK","doc":"- `:user_url_params` - Parameters to send along with the user fetch request,\n  optional, defaults to `[]`\n\nSee `Assent.Strategy.OAuth2` for more.","ref":"Assent.Strategy.VK.html#module-configuration"},{"type":"module","title":"Usage - Assent.Strategy.VK","doc":"config = [\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      client_secret: \"REPLACE_WITH_CLIENT_SECRET\",\n      redirect_uri: \"http://localhost:4000/auth/callback\"\n    ]","ref":"Assent.Strategy.VK.html#module-usage"},{"type":"module","title":"Assent.Strategy.Zitadel","doc":"Zitadel Sign In OIDC strategy.","ref":"Assent.Strategy.Zitadel.html"},{"type":"module","title":"Configuration - Assent.Strategy.Zitadel","doc":"- `:resource_id` - The resource id, required\n\nSee `Assent.Strategy.OIDC` for more configuration options.","ref":"Assent.Strategy.Zitadel.html#module-configuration"},{"type":"module","title":"Usage - Assent.Strategy.Zitadel","doc":"config = [\n      base_url: \"REPLACE_WITH_ORGANIZATION_URL\",\n      client_id: \"REPLACE_WITH_CLIENT_ID\",\n      resource_id: \"REPLACE_WITH_RESOURCE_ID\"\n    ]","ref":"Assent.Strategy.Zitadel.html#module-usage"},{"type":"behaviour","title":"Assent.HTTPAdapter","doc":"HTTP adapter helper module.\n\nYou can configure the which HTTP adapter Assent uses by setting the\nconfiguring:\n\n    http_adapter: Assent.HTTPAdapter.Httpc\n\nDefault options can be set by passing a list of options:\n\n    http_adapter: {Assent.HTTPAdapter.Httpc, [...]}\n\nYou can also set global application config:\n\n    config :assent, :http_adapter, Assent.HTTPAdapter.Httpc","ref":"Assent.HTTPAdapter.html"},{"type":"behaviour","title":"Usage - Assent.HTTPAdapter","doc":"defmodule MyApp.MyHTTPAdapter do\n      @behaviour Assent.HTTPAdapter\n\n      @impl true\n      def request(method, url, body, headers, opts) do\n        # ...\n      end\n    end","ref":"Assent.HTTPAdapter.html#module-usage"},{"type":"type","title":"Assent.HTTPAdapter.body/0","doc":"","ref":"Assent.HTTPAdapter.html#t:body/0"},{"type":"function","title":"Assent.HTTPAdapter.decode_response/2","doc":"Decodes request response body.","ref":"Assent.HTTPAdapter.html#decode_response/2"},{"type":"function","title":"Options - Assent.HTTPAdapter.decode_response/2","doc":"- `:json_library` - The JSON library to use, see\n  `Assent.json_library/1`","ref":"Assent.HTTPAdapter.html#decode_response/2-options"},{"type":"type","title":"Assent.HTTPAdapter.headers/0","doc":"","ref":"Assent.HTTPAdapter.html#t:headers/0"},{"type":"type","title":"Assent.HTTPAdapter.method/0","doc":"","ref":"Assent.HTTPAdapter.html#t:method/0"},{"type":"function","title":"Assent.HTTPAdapter.request/5","doc":"Makes a HTTP request.","ref":"Assent.HTTPAdapter.html#request/5"},{"type":"function","title":"Options - Assent.HTTPAdapter.request/5","doc":"- `:http_adapter` - The HTTP adapter to use, defaults to\n  `Assent.HTTPAdapter.Req`.\n- `:json_library` - The JSON library to use, see\n  `Assent.json_library/1`.","ref":"Assent.HTTPAdapter.html#request/5-options"},{"type":"callback","title":"Assent.HTTPAdapter.request/5","doc":"","ref":"Assent.HTTPAdapter.html#c:request/5"},{"type":"function","title":"Assent.HTTPAdapter.user_agent_header/0","doc":"Sets a user agent header.\n\nThe header value will be `Assent-VERSION` with VERSION being the `:vsn` of\n`:assent` app.","ref":"Assent.HTTPAdapter.html#user_agent_header/0"},{"type":"module","title":"Assent.HTTPAdapter.Finch","doc":"HTTP adapter module for making http requests with Finch.\n\nThe Finch adapter must be configured with the supervisor by passing it as an\noption:\n\n    http_adapter: {Assent.HTTPAdapter.Finch, [supervisor: MyFinch]}\n\nSee `Assent.HTTPAdapter` for more.","ref":"Assent.HTTPAdapter.Finch.html"},{"type":"module","title":"Assent.HTTPAdapter.HTTPResponse","doc":"Struct used by HTTP adapters to normalize HTTP responses.","ref":"Assent.HTTPAdapter.HTTPResponse.html"},{"type":"function","title":"Assent.HTTPAdapter.HTTPResponse.format/1","doc":"","ref":"Assent.HTTPAdapter.HTTPResponse.html#format/1"},{"type":"type","title":"Assent.HTTPAdapter.HTTPResponse.header/0","doc":"","ref":"Assent.HTTPAdapter.HTTPResponse.html#t:header/0"},{"type":"type","title":"Assent.HTTPAdapter.HTTPResponse.t/0","doc":"","ref":"Assent.HTTPAdapter.HTTPResponse.html#t:t/0"},{"type":"module","title":"Assent.HTTPAdapter.Httpc","doc":"HTTP adapter module for making http requests with `:httpc`.\n\nSSL support will automatically be enabled if the `:certifi` and\n`:ssl_verify_fun` libraries exists in your project. You can also override\nthe `:httpc` options by updating the configuration:\n\n    http_adapter: {Assent.HTTPAdapter.Httpc, [...]}\n\nFor releases please make sure you have included `:inets` in your application:\n\n    extra_applications: [:inets]\n\nSee `Assent.HTTPAdapter` for more.","ref":"Assent.HTTPAdapter.Httpc.html"},{"type":"module","title":"Assent.HTTPAdapter.Req","doc":"HTTP adapter module for making http requests with Req.\n\nYou can also override the Req options by updating the configuration:\n\n    http_adapter: {Assent.HTTPAdapter.Req, [...]}\n\nSee `Assent.HTTPAdapter` for more.","ref":"Assent.HTTPAdapter.Req.html"},{"type":"behaviour","title":"Assent.JWTAdapter","doc":"JWT adapter helper module.\n\nYou can configure the JWT adapter by updating the configuration:\n\n    jwt_adapter: {Assent.JWTAdapter.AssentJWT, [...]}\n\nDefault options can be set by passing a list of options:\n\n    jwt_adapter: {Assent.JWTAdapter.AssentJWT, [...]}\n\nYou can also set global application config:\n\n    config :assent, :jwt_adapter, Assent.JWTAdapter.AssentJWT","ref":"Assent.JWTAdapter.html"},{"type":"behaviour","title":"Usage - Assent.JWTAdapter","doc":"defmodule MyApp.MyJWTAdapter do\n      @behaviour Assent.JWTAdapter\n\n      @impl true\n      def sign(claims, alg, secret, opts) do\n        # ...\n      end\n\n      @impl true\n      def verify(token, secret, opts) do\n        # ...\n      end\n    end","ref":"Assent.JWTAdapter.html#module-usage"},{"type":"function","title":"Assent.JWTAdapter.load_private_key/1","doc":"Loads a private key from the provided configuration.","ref":"Assent.JWTAdapter.html#load_private_key/1"},{"type":"function","title":"Options - Assent.JWTAdapter.load_private_key/1","doc":"- `:private_key_path` - The path to the private key file, optional.\n- `:private_key` - The private key, required if `:private_key_path` is not set.","ref":"Assent.JWTAdapter.html#load_private_key/1-options"},{"type":"function","title":"Assent.JWTAdapter.sign/4","doc":"Generates a signed JSON Web Token signature.","ref":"Assent.JWTAdapter.html#sign/4"},{"type":"function","title":"Options - Assent.JWTAdapter.sign/4","doc":"- `:json_library` - The JSON library to use, optional, see\n  `Assent.json_library/1`.\n- `:jwt_adapter` - The JWT adapter module to use, optional, defaults to\n  `Assent.JWTAdapter.AssentJWT`","ref":"Assent.JWTAdapter.html#sign/4-options"},{"type":"callback","title":"Assent.JWTAdapter.sign/4","doc":"","ref":"Assent.JWTAdapter.html#c:sign/4"},{"type":"function","title":"Assent.JWTAdapter.verify/3","doc":"Verifies the JSON Web Token signature.","ref":"Assent.JWTAdapter.html#verify/3"},{"type":"function","title":"Options - Assent.JWTAdapter.verify/3","doc":"- `:json_library` - The JSON library to use, optional, see\n  `Assent.json_library/1`.\n- `:jwt_adapter` - The JWT adapter module to use, optional, defaults to\n  `Assent.JWTAdapter.AssentJWT`","ref":"Assent.JWTAdapter.html#verify/3-options"},{"type":"callback","title":"Assent.JWTAdapter.verify/3","doc":"","ref":"Assent.JWTAdapter.html#c:verify/3"},{"type":"module","title":"Assent.JWTAdapter.AssentJWT","doc":"JWT adapter module for parsing JSON Web Tokens natively.\n\nYou can append options to the configuration:\n\n    jwt_adapter: {Assent.JWTAdapter.AssentJWT, [...]}\n\nSee `Assent.JWTAdapter` for more.","ref":"Assent.JWTAdapter.AssentJWT.html"},{"type":"module","title":"Assent.JWTAdapter.JOSE","doc":"JWT adapter module for parsing JSON Web Tokens with JOSE.\n\nYou can append options to the configuration:\n\n    jwt_adapter: {Assent.JWTAdapter.JOSE, [...]}\n\nSee `Assent.JWTAdapter` for more.","ref":"Assent.JWTAdapter.JOSE.html"},{"type":"exception","title":"Assent.CallbackCSRFError","doc":"","ref":"Assent.CallbackCSRFError.html"},{"type":"function","title":"Assent.CallbackCSRFError.message/1","doc":"","ref":"Assent.CallbackCSRFError.html#message/1"},{"type":"type","title":"Assent.CallbackCSRFError.t/0","doc":"","ref":"Assent.CallbackCSRFError.html#t:t/0"},{"type":"exception","title":"Assent.CallbackError","doc":"","ref":"Assent.CallbackError.html"},{"type":"exception","title":"Assent.CastClaimsError","doc":"","ref":"Assent.CastClaimsError.html"},{"type":"function","title":"Assent.CastClaimsError.message/1","doc":"","ref":"Assent.CastClaimsError.html#message/1"},{"type":"type","title":"Assent.CastClaimsError.t/0","doc":"","ref":"Assent.CastClaimsError.html#t:t/0"},{"type":"exception","title":"Assent.InvalidResponseError","doc":"","ref":"Assent.InvalidResponseError.html"},{"type":"function","title":"Assent.InvalidResponseError.message/1","doc":"","ref":"Assent.InvalidResponseError.html#message/1"},{"type":"type","title":"Assent.InvalidResponseError.t/0","doc":"","ref":"Assent.InvalidResponseError.html#t:t/0"},{"type":"exception","title":"Assent.JWTAdapter.AssentJWT.Error","doc":"","ref":"Assent.JWTAdapter.AssentJWT.Error.html"},{"type":"exception","title":"Assent.MissingConfigError","doc":"","ref":"Assent.MissingConfigError.html"},{"type":"function","title":"Assent.MissingConfigError.message/1","doc":"","ref":"Assent.MissingConfigError.html#message/1"},{"type":"type","title":"Assent.MissingConfigError.t/0","doc":"","ref":"Assent.MissingConfigError.html#t:t/0"},{"type":"exception","title":"Assent.MissingParamError","doc":"","ref":"Assent.MissingParamError.html"},{"type":"function","title":"Assent.MissingParamError.message/1","doc":"","ref":"Assent.MissingParamError.html#message/1"},{"type":"type","title":"Assent.MissingParamError.t/0","doc":"","ref":"Assent.MissingParamError.html#t:t/0"},{"type":"exception","title":"Assent.RequestError","doc":"","ref":"Assent.RequestError.html"},{"type":"type","title":"Assent.RequestError.t/0","doc":"","ref":"Assent.RequestError.html#t:t/0"},{"type":"exception","title":"Assent.ServerUnreachableError","doc":"","ref":"Assent.ServerUnreachableError.html"},{"type":"function","title":"Assent.ServerUnreachableError.message/1","doc":"","ref":"Assent.ServerUnreachableError.html#message/1"},{"type":"type","title":"Assent.ServerUnreachableError.t/0","doc":"","ref":"Assent.ServerUnreachableError.html#t:t/0"},{"type":"exception","title":"Assent.UnexpectedResponseError","doc":"","ref":"Assent.UnexpectedResponseError.html"},{"type":"function","title":"Assent.UnexpectedResponseError.message/1","doc":"","ref":"Assent.UnexpectedResponseError.html#message/1"},{"type":"type","title":"Assent.UnexpectedResponseError.t/0","doc":"","ref":"Assent.UnexpectedResponseError.html#t:t/0"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"CHANGELOG.html"},{"type":"extras","title":"v0.3.1 (2025-06-20) - Changelog","doc":"","ref":"CHANGELOG.html#v0-3-1-2025-06-20"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* `Assent.JWTAdapter.AssentJWT` fixed padding issue with ECDSA that caused invalid signatures","ref":"CHANGELOG.html#bug-fixes"},{"type":"extras","title":"v0.3.0 (2025-01-06) - Changelog","doc":"**This release consists of breaking changes.**\n\nUserinfo is now cast to the correct type per https://openid.net/specs/openid-connect-core-1_0.html#rfc.section.5.1. When upgrading you must ensure that you do not depend on a specific type in the returned userinfo for any of the strategies listed below.","ref":"CHANGELOG.html#v0-3-0-2025-01-06"},{"type":"extras","title":"Breaking changes - Changelog","doc":"* `Assent.Strategy.Auth0.authorize_url/2` no longer accepts `:domain` config, use `:base_url` instead\n* `Assent.Strategy.Basecamp.callback/2` now encodes `sub` as a `binary()` instead of an `integer()`\n* `Assent.Strategy.Github.callback/2` now encodes `sub` as a `binary()` instead of an `integer()`\n* `Assent.Strategy.Google` now encodes `email_verified` as a `boolean()` instead of a `binary()`\n* `Assent.Strategy.Google` now return `hd` instead of `google_hd`\n* `Assent.Strategy.Strava.callback/2` now encodes `sub` as a `binary()` instead of an `integer()`\n* `Assent.Strategy.Telegram.callback/2` now encodes `sub` as a `binary()` instead of an `integer()`\n* `Assent.Strategy.Twitter.callback/2` now encodes `sub` as a `binary()` instead of an `integer()`\n* `Assent.Strategy.VK.callback/2` now encodes `sub` as a `binary()` instead of an `integer()`\n* `:site` configuration option removed, use `:base_url` instead\n* `Assent.Strategy.OAuth2.authorize_url/2` no longer allows `:state` in `:authorization_params`\n* `Assent.Strategy.decode_response/2`removed, use `Assent.HTTPAdapter.decode_response/2` instead\n* `Assent.Strategy.request/5` removed, use `Assent.Strategy.http_request/5` instead\n* `Assent.Strategy.prune/1` removed\n* `Assent.MissingParamError` no longer accepts `:expected_key`, use `:key` instead\n* `Assent.HTTPAdapter.Mint` removed\n* `Assent.Config` removed","ref":"CHANGELOG.html#breaking-changes"},{"type":"extras","title":"Changes - Changelog","doc":"* `Assent.Strategy.Auth0` now uses OIDC instead of OAuth 2.0 base strategy\n* `Assent.Strategy.Gitlab` now uses OIDC instead of OAuth 2.0 base strategy\n* `Assent.Strategy.Google` now uses OIDC instead of OAuth 2.0 base strategy\n* `Assent.Strategy.normalize_userinfo/2` now casts the user claims per OpenID specification","ref":"CHANGELOG.html#changes"},{"type":"extras","title":"v0.2 - Changelog","doc":"The CHANGELOG for v0.2 releases can be found [in the v0.2 branch](https://github.com/pow-auth/assent/blob/v0.2/CHANGELOG.md).","ref":"CHANGELOG.html#v0-2"}],"content_type":"text/markdown","proglang":"elixir","producer":{"name":"ex_doc","version":"0.37.2"}}